/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __PROFILE_BPF_SKEL_H__
#define __PROFILE_BPF_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct profile_bpf {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *pids;
		struct bpf_map *tids;
		struct bpf_map *stackmap;
		struct bpf_map *counts;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *do_perf_event;
	} progs;
	struct {
		struct bpf_link *do_perf_event;
	} links;
	struct profile_bpf__rodata {
		bool kernel_stacks_only;
		bool user_stacks_only;
		bool include_idle;
		bool filter_by_pid;
		bool filter_by_tid;
		bool use_pidns;
		__u64 pidns_dev;
		__u64 pidns_ino;
	} *rodata;

#ifdef __cplusplus
	static inline struct profile_bpf *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct profile_bpf *open_and_load();
	static inline int load(struct profile_bpf *skel);
	static inline int attach(struct profile_bpf *skel);
	static inline void detach(struct profile_bpf *skel);
	static inline void destroy(struct profile_bpf *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
profile_bpf__destroy(struct profile_bpf *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
profile_bpf__create_skeleton(struct profile_bpf *obj);

static inline struct profile_bpf *
profile_bpf__open_opts(const struct bpf_object_open_opts *opts)
{
	struct profile_bpf *obj;
	int err;

	obj = (struct profile_bpf *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = profile_bpf__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	profile_bpf__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct profile_bpf *
profile_bpf__open(void)
{
	return profile_bpf__open_opts(NULL);
}

static inline int
profile_bpf__load(struct profile_bpf *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct profile_bpf *
profile_bpf__open_and_load(void)
{
	struct profile_bpf *obj;
	int err;

	obj = profile_bpf__open();
	if (!obj)
		return NULL;
	err = profile_bpf__load(obj);
	if (err) {
		profile_bpf__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
profile_bpf__attach(struct profile_bpf *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
profile_bpf__detach(struct profile_bpf *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *profile_bpf__elf_bytes(size_t *sz);

static inline int
profile_bpf__create_skeleton(struct profile_bpf *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "profile_bpf";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 5;
	s->map_skel_sz = 24;
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt,
			sizeof(*s->maps) > 24 ? sizeof(*s->maps) : 24);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	map = (struct bpf_map_skeleton *)((char *)s->maps + 0 * s->map_skel_sz);
	map->name = "pids";
	map->map = &obj->maps.pids;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 1 * s->map_skel_sz);
	map->name = "tids";
	map->map = &obj->maps.tids;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 2 * s->map_skel_sz);
	map->name = "stackmap";
	map->map = &obj->maps.stackmap;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 3 * s->map_skel_sz);
	map->name = "counts";
	map->map = &obj->maps.counts;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 4 * s->map_skel_sz);
	map->name = "profile_.rodata";
	map->map = &obj->maps.rodata;
	map->mmaped = (void **)&obj->rodata;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "do_perf_event";
	s->progs[0].prog = &obj->progs.do_perf_event;
	s->progs[0].link = &obj->links.do_perf_event;

	s->data = profile_bpf__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *profile_bpf__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1b\x78\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0e\0\
\x01\xbf\x61\0\0\0\0\0\0\xb4\x10\0\0\0\0\0\0\x63\xa1\xff\xf8\0\0\0\0\xb7\x10\0\
\0\0\0\0\0\x7b\xa1\xff\xf0\0\0\0\0\x7b\xa1\xff\xe8\0\0\0\0\x7b\xa1\xff\xe0\0\0\
\0\0\x7b\xa1\xff\xd0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\0\0\
\0\0\0\x56\x10\0\x11\0\0\0\x01\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x11\0\0\
\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x22\0\0\0\0\0\0\xbf\x3a\0\0\0\
\0\0\0\x07\x30\0\0\xff\xff\xff\xd0\xb4\x40\0\0\0\0\0\x08\x85\0\0\0\0\0\0\x78\
\x55\0\0\x06\0\0\0\0\xbf\x1a\0\0\0\0\0\0\x07\x10\0\0\xff\xff\xff\xd0\x61\x21\0\
\x04\0\0\0\0\x63\xa2\xff\xdc\0\0\0\0\x61\x01\0\0\0\0\0\0\x05\0\0\x04\0\0\0\0\
\x85\0\0\0\0\0\0\x0e\xbf\x10\0\0\0\0\0\0\x77\x10\0\0\0\0\0\x20\x63\xa1\xff\xdc\
\0\0\0\0\x63\xa0\xff\xd8\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\
\0\0\0\0\0\x56\x10\0\x01\0\0\0\0\x16\0\0\x4d\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x71\x11\0\0\0\0\0\0\x56\x10\0\x06\0\0\0\x01\xbf\x2a\0\0\0\0\0\0\x07\
\x20\0\0\xff\xff\xff\xdc\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\
\x01\x15\0\0\x43\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\0\0\0\0\
\0\x56\x10\0\x06\0\0\0\x01\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xd8\x18\
\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\x15\0\0\x39\0\0\0\0\x61\
\x1a\xff\xdc\0\0\0\0\x63\xa1\xff\xe0\0\0\0\0\xbf\x1a\0\0\0\0\0\0\x07\x10\0\0\
\xff\xff\xff\xec\xb4\x20\0\0\0\0\0\x10\x85\0\0\0\0\0\0\x10\xb4\x70\0\0\xff\xff\
\xff\xff\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\0\0\0\0\0\xb4\0\0\0\xff\
\xff\xff\xff\x56\x10\0\x07\0\0\0\0\xb7\x20\0\0\0\0\0\0\xbf\x16\0\0\0\0\0\0\x0f\
\x12\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\x85\0\
\0\0\0\0\0\x1b\x63\xa0\xff\xe8\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\
\x11\0\0\0\0\0\0\x56\x10\0\x08\0\0\0\0\xb7\x10\0\0\0\0\0\0\x0f\x61\0\0\0\0\0\0\
\xbf\x16\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\x01\0\
\x85\0\0\0\0\0\0\x1b\xbf\x70\0\0\0\0\0\0\x63\xa7\xff\xe4\0\0\0\0\xbf\x2a\0\0\0\
\0\0\0\x07\x20\0\0\xff\xff\xff\xe0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\
\0\0\0\0\x01\x55\0\0\x10\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\
\xe0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x30\0\0\0\0\0\x18\0\0\0\0\0\0\0\0\
\xb7\x40\0\0\0\0\0\x01\x85\0\0\0\0\0\0\x02\x16\0\0\x01\0\0\0\0\x56\0\0\x08\xff\
\xff\xff\xef\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xe0\x18\x10\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\x15\0\0\x02\0\0\0\0\xb7\x10\0\0\0\0\0\
\x01\xdb\x01\0\0\0\0\0\x01\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x47\x50\x4c\0\xeb\x9f\x01\0\0\0\0\x18\0\
\0\0\0\0\0\x05\xe8\0\0\x05\xe8\0\0\x06\x27\0\0\0\0\x02\0\0\0\0\0\0\x03\0\0\0\
\x01\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\
\x04\0\0\0\x01\0\0\0\x05\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\
\x06\0\0\0\x19\x08\0\0\0\0\0\0\x07\0\0\0\x1d\x08\0\0\0\0\0\0\x08\0\0\0\x23\x01\
\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x0a\0\0\0\x30\x08\0\0\0\0\0\
\0\x0b\0\0\0\x33\x08\0\0\0\0\0\0\x0c\0\0\0\x38\x01\0\0\0\0\0\0\x01\0\0\0\x08\0\
\0\0\0\x02\0\0\0\0\0\0\x0e\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\
\x1e\0\0\0\0\x04\0\0\x04\0\0\0\x20\0\0\0\x46\0\0\0\x01\0\0\0\0\0\0\0\x4b\0\0\0\
\x05\0\0\0\x40\0\0\0\x4f\0\0\0\x09\0\0\0\x80\0\0\0\x55\0\0\0\x0d\0\0\0\xc0\0\0\
\0\x61\x0e\0\0\0\0\0\0\x0f\0\0\0\x01\0\0\0\0\x04\0\0\x04\0\0\0\x20\0\0\0\x46\0\
\0\0\x01\0\0\0\0\0\0\0\x4b\0\0\0\x05\0\0\0\x40\0\0\0\x4f\0\0\0\x09\0\0\0\x80\0\
\0\0\x55\0\0\0\x0d\0\0\0\xc0\0\0\0\x66\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\0\
\x02\0\0\0\0\0\0\x14\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x07\0\
\0\0\0\x04\0\0\x02\0\0\0\x10\0\0\0\x46\0\0\0\x13\0\0\0\0\0\0\0\x4b\0\0\0\x05\0\
\0\0\x40\0\0\0\x6b\x0e\0\0\0\0\0\0\x15\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x18\0\
\0\0\x74\x04\0\0\x04\0\0\0\x1c\0\0\0\x7a\0\0\0\x07\0\0\0\0\0\0\0\x7e\0\0\0\x02\
\0\0\0\x20\0\0\0\x8c\0\0\0\x02\0\0\0\x40\0\0\0\x9a\0\0\0\x1a\0\0\0\x60\0\0\0\
\x9f\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x19\0\0\0\
\x04\0\0\0\x10\0\0\0\0\x02\0\0\0\0\0\0\x1c\0\0\0\xa4\x08\0\0\0\0\0\0\x1d\0\0\0\
\xa8\x08\0\0\0\0\0\0\x1e\0\0\0\xae\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\0\0\x02\0\
\0\0\0\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\x28\0\0\0\0\0\
\x04\0\0\x04\0\0\0\x20\0\0\0\x46\0\0\0\x01\0\0\0\0\0\0\0\x4b\0\0\0\x17\0\0\0\
\x40\0\0\0\x4f\0\0\0\x1b\0\0\0\x80\0\0\0\x55\0\0\0\x1f\0\0\0\xc0\0\0\0\xc1\x0e\
\0\0\0\0\0\0\x21\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x24\0\0\0\xc8\x04\0\0\x03\0\
\0\0\xa8\0\0\0\xdc\0\0\0\x25\0\0\0\0\0\0\0\xe1\0\0\0\x1d\0\0\x04\xc0\0\0\0\xef\
\0\0\0\x1d\0\0\x05\0\0\0\0\xf4\x08\0\0\0\0\0\0\x26\0\0\x01\x07\x08\0\0\0\0\0\0\
\x27\0\0\0\0\x04\0\0\x03\0\0\0\x98\0\0\x01\x14\0\0\0\x29\0\0\0\0\0\0\x01\x19\0\
\0\0\x2a\0\0\0\x40\0\0\x01\x1d\0\0\0\x2c\0\0\0\xc0\0\0\x01\x22\x01\0\0\0\0\0\0\
\x08\0\0\0\x40\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x28\0\0\0\x04\0\0\0\x01\0\0\x01\
\x30\x08\0\0\0\0\0\0\x2b\0\0\0\0\x04\0\0\x02\0\0\0\x10\0\0\x01\x36\0\0\0\x28\0\
\0\0\0\0\0\0\xef\0\0\0\x28\0\0\0\x40\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x28\0\0\0\
\x04\0\0\0\x10\0\0\0\0\x0d\0\0\x01\0\0\0\x02\0\0\x01\x3b\0\0\0\x23\0\0\x01\x3f\
\x0c\0\0\x01\0\0\0\x2d\0\0\x02\x5a\x04\0\0\x02\0\0\0\x08\0\0\0\x7a\0\0\0\x07\0\
\0\0\0\0\0\x02\x69\0\0\0\x07\0\0\0\x20\0\0\0\0\x0a\0\0\0\0\0\0\x31\0\0\0\0\x09\
\0\0\0\0\0\0\x32\0\0\x05\x80\x08\0\0\0\0\0\0\x33\0\0\x05\x85\x01\0\0\0\0\0\0\
\x01\x04\0\0\x08\0\0\x05\x8b\x0e\0\0\0\0\0\0\x30\0\0\0\x01\0\0\x05\x9e\x0e\0\0\
\0\0\0\0\x30\0\0\0\x01\0\0\x05\xaf\x0e\0\0\0\0\0\0\x30\0\0\0\x01\0\0\x05\xbc\
\x0e\0\0\0\0\0\0\x30\0\0\0\x01\0\0\x05\xca\x0e\0\0\0\0\0\0\x30\0\0\0\x01\0\0\
\x05\xd8\x0e\0\0\0\0\0\0\x30\0\0\0\x01\0\0\0\0\x0a\0\0\0\0\0\0\x3b\0\0\0\0\x09\
\0\0\0\0\0\0\x1d\0\0\x05\xe2\x0e\0\0\0\0\0\0\x3a\0\0\0\x01\0\0\x05\xec\x0e\0\0\
\0\0\0\0\x3a\0\0\0\x01\0\0\0\0\x0a\0\0\0\0\0\0\x1c\0\0\x05\xf6\x0e\0\0\0\0\0\0\
\x3e\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x19\0\0\0\x04\0\0\0\x04\0\0\x06\
\x09\x0e\0\0\0\0\0\0\x40\0\0\0\x01\0\0\x06\x11\x0f\0\0\x04\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\x20\0\0\0\x12\0\0\0\0\0\0\0\x20\0\0\0\x16\0\0\0\0\0\0\0\x10\0\0\0\
\x22\0\0\0\0\0\0\0\x20\0\0\x06\x17\x0f\0\0\x09\0\0\0\0\0\0\0\x34\0\0\0\0\0\0\0\
\x01\0\0\0\x35\0\0\0\0\0\0\0\x01\0\0\0\x36\0\0\0\0\0\0\0\x01\0\0\0\x37\0\0\0\0\
\0\0\0\x01\0\0\0\x38\0\0\0\0\0\0\0\x01\0\0\0\x39\0\0\0\0\0\0\0\x01\0\0\0\x3c\0\
\0\0\0\0\0\0\x08\0\0\0\x3d\0\0\0\0\0\0\0\x08\0\0\0\x3f\0\0\0\x18\0\0\0\x08\0\0\
\x06\x1f\x0f\0\0\x01\0\0\0\0\0\0\0\x41\0\0\0\0\0\0\0\x04\0\x69\x6e\x74\0\x5f\
\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x75\
\x33\x32\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\
\x74\0\x75\x38\0\x5f\x5f\x75\x38\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x63\x68\
\x61\x72\0\x74\x79\x70\x65\0\x6b\x65\x79\0\x76\x61\x6c\x75\x65\0\x6d\x61\x78\
\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x70\x69\x64\x73\0\x74\x69\x64\x73\0\x73\x74\
\x61\x63\x6b\x6d\x61\x70\0\x6b\x65\x79\x5f\x74\0\x70\x69\x64\0\x75\x73\x65\x72\
\x5f\x73\x74\x61\x63\x6b\x5f\x69\x64\0\x6b\x65\x72\x6e\x5f\x73\x74\x61\x63\x6b\
\x5f\x69\x64\0\x6e\x61\x6d\x65\0\x63\x68\x61\x72\0\x75\x36\x34\0\x5f\x5f\x75\
\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\
\x67\0\x63\x6f\x75\x6e\x74\x73\0\x62\x70\x66\x5f\x70\x65\x72\x66\x5f\x65\x76\
\x65\x6e\x74\x5f\x64\x61\x74\x61\0\x72\x65\x67\x73\0\x73\x61\x6d\x70\x6c\x65\
\x5f\x70\x65\x72\x69\x6f\x64\0\x61\x64\x64\x72\0\x62\x70\x66\x5f\x75\x73\x65\
\x72\x5f\x70\x74\x5f\x72\x65\x67\x73\x5f\x74\0\x75\x73\x65\x72\x5f\x70\x74\x5f\
\x72\x65\x67\x73\0\x61\x72\x67\x73\0\x70\x73\x77\0\x67\x70\x72\x73\0\x75\x6e\
\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\0\x70\x73\x77\x5f\x74\0\x6d\x61\
\x73\x6b\0\x63\x74\x78\0\x64\x6f\x5f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\0\
\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\
\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x62\x63\x63\x2d\x30\x2e\
\x33\x33\x2e\x30\x2d\x62\x75\x69\x6c\x64\x2f\x62\x63\x63\x2d\x30\x2e\x33\x33\
\x2e\x30\x2f\x6c\x69\x62\x62\x70\x66\x2d\x74\x6f\x6f\x6c\x73\x2f\x70\x72\x6f\
\x66\x69\x6c\x65\x2e\x62\x70\x66\x2e\x63\0\x69\x6e\x74\x20\x64\x6f\x5f\x70\x65\
\x72\x66\x5f\x65\x76\x65\x6e\x74\x28\x73\x74\x72\x75\x63\x74\x20\x62\x70\x66\
\x5f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x20\x2a\x63\
\x74\x78\x29\0\x09\x73\x74\x72\x75\x63\x74\x20\x6b\x65\x79\x5f\x74\x20\x6b\x65\
\x79\x20\x3d\x20\x7b\x7d\x3b\0\x09\x73\x74\x72\x75\x63\x74\x20\x62\x70\x66\x5f\
\x70\x69\x64\x6e\x73\x5f\x69\x6e\x66\x6f\x20\x6e\x73\x20\x3d\x20\x7b\x7d\x3b\0\
\x09\x69\x66\x20\x28\x75\x73\x65\x5f\x70\x69\x64\x6e\x73\x20\x26\x26\x20\x21\
\x62\x70\x66\x5f\x67\x65\x74\x5f\x6e\x73\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\
\x70\x69\x64\x5f\x74\x67\x69\x64\x28\x70\x69\x64\x6e\x73\x5f\x64\x65\x76\x2c\
\x20\x70\x69\x64\x6e\x73\x5f\x69\x6e\x6f\x2c\x20\x26\x6e\x73\x2c\0\x62\x70\x66\
\x5f\x70\x69\x64\x6e\x73\x5f\x69\x6e\x66\x6f\0\x74\x67\x69\x64\0\x30\x3a\x31\0\
\x09\x09\x70\x69\x64\x20\x3d\x20\x6e\x73\x2e\x74\x67\x69\x64\x3b\0\x30\x3a\x30\
\0\x09\x09\x74\x69\x64\x20\x3d\x20\x6e\x73\x2e\x70\x69\x64\x3b\0\x09\x7d\x20\
\x65\x6c\x73\x65\x20\x7b\0\x09\x09\x69\x64\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\
\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x70\x69\x64\x5f\x74\x67\x69\x64\x28\
\x29\x3b\0\x09\x09\x70\x69\x64\x20\x3d\x20\x69\x64\x20\x3e\x3e\x20\x33\x32\x3b\
\0\x09\x69\x66\x20\x28\x21\x69\x6e\x63\x6c\x75\x64\x65\x5f\x69\x64\x6c\x65\x20\
\x26\x26\x20\x74\x69\x64\x20\x3d\x3d\x20\x30\x29\0\x09\x69\x66\x20\x28\x66\x69\
\x6c\x74\x65\x72\x5f\x62\x79\x5f\x70\x69\x64\x20\x26\x26\x20\x21\x62\x70\x66\
\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x70\
\x69\x64\x73\x2c\x20\x26\x70\x69\x64\x29\x29\0\x09\x69\x66\x20\x28\x66\x69\x6c\
\x74\x65\x72\x5f\x62\x79\x5f\x74\x69\x64\x20\x26\x26\x20\x21\x62\x70\x66\x5f\
\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x74\x69\
\x64\x73\x2c\x20\x26\x74\x69\x64\x29\x29\0\x09\x6b\x65\x79\x2e\x70\x69\x64\x20\
\x3d\x20\x70\x69\x64\x3b\0\x09\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\
\x65\x6e\x74\x5f\x63\x6f\x6d\x6d\x28\x26\x6b\x65\x79\x2e\x6e\x61\x6d\x65\x2c\
\x20\x73\x69\x7a\x65\x6f\x66\x28\x6b\x65\x79\x2e\x6e\x61\x6d\x65\x29\x29\x3b\0\
\x09\x69\x66\x20\x28\x75\x73\x65\x72\x5f\x73\x74\x61\x63\x6b\x73\x5f\x6f\x6e\
\x6c\x79\x29\0\x09\x09\x6b\x65\x79\x2e\x6b\x65\x72\x6e\x5f\x73\x74\x61\x63\x6b\
\x5f\x69\x64\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x73\x74\x61\x63\x6b\
\x69\x64\x28\x26\x63\x74\x78\x2d\x3e\x72\x65\x67\x73\x2c\x20\x26\x73\x74\x61\
\x63\x6b\x6d\x61\x70\x2c\x20\x30\x29\x3b\0\x09\x69\x66\x20\x28\x6b\x65\x72\x6e\
\x65\x6c\x5f\x73\x74\x61\x63\x6b\x73\x5f\x6f\x6e\x6c\x79\x29\0\x09\x09\x6b\x65\
\x79\x2e\x75\x73\x65\x72\x5f\x73\x74\x61\x63\x6b\x5f\x69\x64\x20\x3d\x20\x62\
\x70\x66\x5f\x67\x65\x74\x5f\x73\x74\x61\x63\x6b\x69\x64\x28\x26\x63\x74\x78\
\x2d\x3e\x72\x65\x67\x73\x2c\x20\x26\x73\x74\x61\x63\x6b\x6d\x61\x70\x2c\0\x2f\
\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\
\x44\x2f\x62\x63\x63\x2d\x30\x2e\x33\x33\x2e\x30\x2d\x62\x75\x69\x6c\x64\x2f\
\x62\x63\x63\x2d\x30\x2e\x33\x33\x2e\x30\x2f\x6c\x69\x62\x62\x70\x66\x2d\x74\
\x6f\x6f\x6c\x73\x2f\x2e\x2f\x6d\x61\x70\x73\x2e\x62\x70\x66\x2e\x68\0\x09\x76\
\x61\x6c\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\
\x5f\x65\x6c\x65\x6d\x28\x6d\x61\x70\x2c\x20\x6b\x65\x79\x29\x3b\0\x09\x69\x66\
\x20\x28\x76\x61\x6c\x29\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\
\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x6d\x61\x70\x2c\x20\
\x6b\x65\x79\x2c\x20\x69\x6e\x69\x74\x2c\x20\x42\x50\x46\x5f\x4e\x4f\x45\x58\
\x49\x53\x54\x29\x3b\0\x09\x69\x66\x20\x28\x65\x72\x72\x20\x26\x26\x20\x65\x72\
\x72\x20\x21\x3d\x20\x2d\x45\x45\x58\x49\x53\x54\x29\0\x09\x72\x65\x74\x75\x72\
\x6e\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\
\x65\x6d\x28\x6d\x61\x70\x2c\x20\x6b\x65\x79\x29\x3b\0\x09\x69\x66\x20\x28\x76\
\x61\x6c\x70\x29\0\x09\x09\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\
\x61\x6e\x64\x5f\x61\x64\x64\x28\x76\x61\x6c\x70\x2c\x20\x31\x29\x3b\0\x7d\0\
\x62\x6f\x6f\x6c\0\x5f\x42\x6f\x6f\x6c\0\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x74\
\x61\x63\x6b\x73\x5f\x6f\x6e\x6c\x79\0\x75\x73\x65\x72\x5f\x73\x74\x61\x63\x6b\
\x73\x5f\x6f\x6e\x6c\x79\0\x69\x6e\x63\x6c\x75\x64\x65\x5f\x69\x64\x6c\x65\0\
\x66\x69\x6c\x74\x65\x72\x5f\x62\x79\x5f\x70\x69\x64\0\x66\x69\x6c\x74\x65\x72\
\x5f\x62\x79\x5f\x74\x69\x64\0\x75\x73\x65\x5f\x70\x69\x64\x6e\x73\0\x70\x69\
\x64\x6e\x73\x5f\x64\x65\x76\0\x70\x69\x64\x6e\x73\x5f\x69\x6e\x6f\0\x64\x6f\
\x5f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x2e\x7a\x65\x72\x6f\0\x4c\x49\x43\
\x45\x4e\x53\x45\0\x2e\x6d\x61\x70\x73\0\x2e\x72\x6f\x64\x61\x74\x61\0\x6c\x69\
\x63\x65\x6e\x73\x65\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x14\0\0\0\x14\0\
\0\x02\xac\0\0\x02\xc0\0\0\0\x4c\0\0\0\x08\0\0\x01\x4d\0\0\0\x01\0\0\0\0\0\0\0\
\x2e\0\0\0\x10\0\0\x01\x4d\0\0\0\x2a\0\0\0\0\0\0\x01\x58\0\0\x01\xa5\0\0\xcc\0\
\0\0\0\x10\0\0\x01\x58\0\0\x01\xd8\0\0\xdc\x0f\0\0\0\x38\0\0\x01\x58\0\0\x01\
\xf0\0\0\xec\x18\0\0\0\x40\0\0\x01\x58\0\0\x02\x10\0\0\xf4\x06\0\0\0\x58\0\0\
\x01\x58\0\0\x02\x10\0\0\xf4\x10\0\0\0\x60\0\0\x01\x58\0\0\x02\x10\0\0\xf4\x30\
\0\0\0\x78\0\0\x01\x58\0\0\x02\x10\0\0\xf4\x3b\0\0\0\xa0\0\0\x01\x58\0\0\x02\
\x10\0\0\xf4\x14\0\0\0\xb0\0\0\x01\x58\0\0\x02\x10\0\0\xf4\x10\0\0\0\xc8\0\0\
\x01\x58\0\0\x02\x72\0\0\xfc\x0c\0\0\0\xd0\0\0\x01\x58\0\0\x02\x72\0\0\xfc\x07\
\0\0\0\xd8\0\0\x01\x58\0\0\x02\x87\0\x01\0\x0c\0\0\0\xe0\0\0\x01\x58\0\0\x02\
\x97\0\x01\x04\x02\0\0\0\xe8\0\0\x01\x58\0\0\x02\xa1\0\x01\x08\x08\0\0\0\xf0\0\
\0\x01\x58\0\0\x02\xc4\0\x01\x0c\x0c\0\0\x01\0\0\0\x01\x58\0\0\x02\xc4\0\x01\
\x0c\x07\0\0\x01\x10\0\0\x01\x58\0\0\x02\xd6\0\x01\x1c\x07\0\0\x01\x28\0\0\x01\
\x58\0\0\x02\xd6\0\x01\x1c\x14\0\0\x01\x38\0\0\x01\x58\0\0\x02\xf6\0\x01\x28\
\x06\0\0\x01\x50\0\0\x01\x58\0\0\x02\xf6\0\x01\x28\x14\0\0\x01\x68\0\0\x01\x58\
\0\0\x02\xf6\0\x01\x28\x18\0\0\x01\x80\0\0\x01\x58\0\0\x02\xf6\0\x01\x28\x14\0\
\0\x01\x88\0\0\x01\x58\0\0\x03\x2f\0\x01\x34\x06\0\0\x01\xa0\0\0\x01\x58\0\0\
\x03\x2f\0\x01\x34\x14\0\0\x01\xb8\0\0\x01\x58\0\0\x03\x2f\0\x01\x34\x18\0\0\
\x01\xd0\0\0\x01\x58\0\0\x03\x2f\0\x01\x34\x14\0\0\x01\xd8\0\0\x01\x58\0\0\x03\
\x68\0\x01\x40\x0c\0\0\x01\xe0\0\0\x01\x58\0\0\x03\x68\0\x01\x40\x0a\0\0\x01\
\xe8\0\0\x01\x58\0\0\x03\x78\0\x01\x44\x1c\0\0\x01\xf8\0\0\x01\x58\0\0\x03\x78\
\0\x01\x44\x02\0\0\x02\x10\0\0\x01\x58\0\0\x03\xac\0\x01\x4c\x06\0\0\x02\x50\0\
\0\x01\x58\0\0\x03\xc3\0\x01\x58\x17\0\0\x02\x78\0\0\x01\x58\0\0\x04\x04\0\x01\
\x60\x06\0\0\x02\xa8\0\0\x01\x58\0\0\x04\x1d\0\x01\x6c\x17\0\0\x02\xf0\0\0\x04\
\x5a\0\0\x04\xa6\0\0\x7c\x08\0\0\x03\x08\0\0\x04\x5a\0\0\x04\xcc\0\0\x80\x06\0\
\0\x03\x20\0\0\x04\x5a\0\0\x04\xd6\0\0\x8c\x08\0\0\x03\x50\0\0\x04\x5a\0\0\x05\
\x0f\0\0\x90\x0a\0\0\x03\x70\0\0\x04\x5a\0\0\x05\x2b\0\0\x9c\x09\0\0\x03\x88\0\
\0\x01\x58\0\0\x05\x52\0\x01\x7c\x06\0\0\x03\x98\0\0\x01\x58\0\0\x05\x5d\0\x01\
\x80\x03\0\0\x03\xa0\0\0\x01\x58\0\0\x05\x7e\0\x01\x8c\x01\0\0\0\x10\0\0\x01\
\x4d\0\0\0\x04\0\0\0\xc8\0\0\0\x2f\0\0\x02\x6e\0\0\0\0\0\0\0\xd8\0\0\0\x2f\0\0\
\x02\x83\0\0\0\0\0\0\x02\x38\0\0\0\x24\0\0\x02\x83\0\0\0\0\0\0\x02\x98\0\0\0\
\x24\0\0\x02\x83\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x89\x01\0\0\x05\0\0\0\0\0\
\0\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\x03\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x51\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\xb0\0\0\0\x6c\x11\0\0\
\x05\0\0\0\0\0\0\0\x05\0\0\0\0\0\0\0\x01\0\0\0\x25\x11\0\0\x05\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x08\0\0\0\x9c\x11\0\0\x05\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x08\0\0\0\xbc\x11\0\0\x05\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\x01\0\0\0\xd7\x11\0\
\0\x05\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\x01\0\0\0\x7b\x11\0\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x20\0\0\0\xc9\x11\0\0\x05\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x01\
\0\0\0\x76\x11\0\0\x06\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x20\0\0\0\x01\x11\0\0\
\x05\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\x80\x11\0\0\x06\0\0\0\0\0\0\0\
\x40\0\0\0\0\0\0\0\x10\0\0\0\x12\x11\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\0\0\0\x5f\x11\0\0\x06\0\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\x20\0\0\x01\x06\x11\0\0\
\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x40\0\0\0\x05\0\0\0\x01\0\
\0\0\0\0\0\0\x60\0\0\0\x06\0\0\0\x01\0\0\0\0\0\0\0\x78\0\0\0\x07\0\0\0\x01\0\0\
\0\0\0\0\x01\x10\0\0\0\x08\0\0\0\x01\0\0\0\0\0\0\x01\x38\0\0\0\x09\0\0\0\x01\0\
\0\0\0\0\0\x01\x68\0\0\0\x0a\0\0\0\x01\0\0\0\0\0\0\x01\x88\0\0\0\x0b\0\0\0\x01\
\0\0\0\0\0\0\x01\xb8\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\x02\x10\0\0\0\x0d\0\0\0\
\x01\0\0\0\0\0\0\x02\x50\0\0\0\x0e\0\0\0\x01\0\0\0\0\0\0\x02\x78\0\0\0\x0f\0\0\
\0\x01\0\0\0\0\0\0\x02\xb0\0\0\0\x0e\0\0\0\x01\0\0\0\0\0\0\x02\xf0\0\0\0\x10\0\
\0\0\x01\0\0\0\0\0\0\x03\x20\0\0\0\x10\0\0\0\x01\0\0\0\0\0\0\x03\x30\0\0\0\x03\
\0\0\0\x01\0\0\0\0\0\0\x03\x70\0\0\0\x10\0\0\0\x01\0\0\0\0\0\0\x05\x44\0\0\0\
\x0a\0\0\0\x04\0\0\0\0\0\0\x05\x50\0\0\0\x0c\0\0\0\x04\0\0\0\0\0\0\x05\x5c\0\0\
\0\x0e\0\0\0\x04\0\0\0\0\0\0\x05\x68\0\0\0\x10\0\0\0\x04\0\0\0\0\0\0\x05\x80\0\
\0\0\x0f\0\0\0\x03\0\0\0\0\0\0\x05\x8c\0\0\0\x0d\0\0\0\x03\0\0\0\0\0\0\x05\x98\
\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\x05\xa4\0\0\0\x09\0\0\0\x03\0\0\0\0\0\0\x05\
\xb0\0\0\0\x0b\0\0\0\x03\0\0\0\0\0\0\x05\xbc\0\0\0\x05\0\0\0\x03\0\0\0\0\0\0\
\x05\xc8\0\0\0\x06\0\0\0\x03\0\0\0\0\0\0\x05\xd4\0\0\0\x07\0\0\0\x03\0\0\0\0\0\
\0\x05\xe0\0\0\0\x03\0\0\0\x03\0\0\0\0\0\0\x05\xf8\0\0\0\x11\0\0\0\x04\0\0\0\0\
\0\0\0\x2c\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x40\0\0\0\x01\0\0\0\x04\0\0\0\0\0\
\0\0\x50\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x60\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\
\0\x70\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x80\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\
\x90\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\xa0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\
\xb0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\xc0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\
\xd0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\xe0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\
\xf0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\
\x10\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x20\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\
\x01\x30\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x40\0\0\0\x01\0\0\0\x04\0\0\0\0\0\
\0\x01\x50\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x60\0\0\0\x01\0\0\0\x04\0\0\0\0\
\0\0\x01\x70\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x80\0\0\0\x01\0\0\0\x04\0\0\0\
\0\0\0\x01\x90\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xa0\0\0\0\x01\0\0\0\x04\0\0\
\0\0\0\0\x01\xb0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xc0\0\0\0\x01\0\0\0\x04\0\
\0\0\0\0\0\x01\xd0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xe0\0\0\0\x01\0\0\0\x04\
\0\0\0\0\0\0\x01\xf0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\0\0\0\0\x01\0\0\0\x04\
\0\0\0\0\0\0\x02\x10\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\x20\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\x02\x30\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\x40\0\0\0\x01\0\0\
\0\x04\0\0\0\0\0\0\x02\x50\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\x60\0\0\0\x01\0\
\0\0\x04\0\0\0\0\0\0\x02\x70\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\x80\0\0\0\x01\
\0\0\0\x04\0\0\0\0\0\0\x02\x90\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\xa0\0\0\0\
\x01\0\0\0\x04\0\0\0\0\0\0\x02\xb0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\xc0\0\0\
\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\xd0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\xec\0\
\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\xfc\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x03\x0c\
\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x03\x1c\0\0\0\x01\0\0\0\x04\x0d\x18\x16\x11\
\x12\x14\x0e\x0f\x10\x03\x13\x15\x17\x19\x1a\0\x75\x73\x65\x72\x5f\x73\x74\x61\
\x63\x6b\x73\x5f\x6f\x6e\x6c\x79\0\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x74\x61\x63\
\x6b\x73\x5f\x6f\x6e\x6c\x79\0\x70\x69\x64\x6e\x73\x5f\x64\x65\x76\0\x2e\x74\
\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\x2e\x65\x78\x74\0\x2e\x72\x65\
\x6c\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\0\x64\x6f\x5f\x70\x65\x72\x66\x5f\
\x65\x76\x65\x6e\x74\0\x63\x6f\x75\x6e\x74\x73\0\x2e\x6d\x61\x70\x73\0\x75\x73\
\x65\x5f\x70\x69\x64\x6e\x73\0\x74\x69\x64\x73\0\x70\x69\x64\x73\0\x73\x74\x61\
\x63\x6b\x6d\x61\x70\0\x64\x6f\x5f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x2e\
\x7a\x65\x72\x6f\0\x70\x69\x64\x6e\x73\x5f\x69\x6e\x6f\0\x2e\x6c\x6c\x76\x6d\
\x5f\x61\x64\x64\x72\x73\x69\x67\0\x6c\x69\x63\x65\x6e\x73\x65\0\x69\x6e\x63\
\x6c\x75\x64\x65\x5f\x69\x64\x6c\x65\0\x66\x69\x6c\x74\x65\x72\x5f\x62\x79\x5f\
\x74\x69\x64\0\x66\x69\x6c\x74\x65\x72\x5f\x62\x79\x5f\x70\x69\x64\0\x2e\x73\
\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x72\x6f\x64\x61\x74\
\x61\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\0\x4c\x49\x43\x45\x4e\x53\x45\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe5\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1a\x67\0\0\0\0\0\0\x01\x0e\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x2f\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\
\0\0\0\0\0\0\0\0\0\0\0\x54\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x40\0\0\0\0\0\0\x03\xb0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\0\0\0\0\x42\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x15\x88\0\
\0\0\0\0\0\x01\0\0\0\0\x0d\0\0\0\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\
\xf5\0\0\0\x01\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\xf0\0\0\0\0\0\
\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x66\0\0\0\x01\
\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x10\0\0\0\0\0\0\0\x70\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\xb4\0\0\0\x01\0\0\0\0\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x80\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x04\x84\0\0\0\0\0\0\x0c\x27\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x04\0\0\0\0\0\0\0\0\0\0\0\xfd\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x16\x88\0\0\0\0\0\0\0\xe0\0\0\0\x0d\0\0\0\x08\0\0\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\x10\0\0\0\x39\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x10\xac\0\0\0\0\0\0\x03\x2c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\
\0\0\0\x35\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x17\x68\0\0\
\0\0\0\0\x02\xf0\0\0\0\x0d\0\0\0\x0a\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\
\xa6\x6f\xff\x4c\x03\0\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1a\x58\0\0\
\0\0\0\0\0\x0f\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\xed\0\0\
\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x13\xd8\0\0\0\0\0\0\x01\xb0\
\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct profile_bpf *profile_bpf::open(const struct bpf_object_open_opts *opts) { return profile_bpf__open_opts(opts); }
struct profile_bpf *profile_bpf::open_and_load() { return profile_bpf__open_and_load(); }
int profile_bpf::load(struct profile_bpf *skel) { return profile_bpf__load(skel); }
int profile_bpf::attach(struct profile_bpf *skel) { return profile_bpf__attach(skel); }
void profile_bpf::detach(struct profile_bpf *skel) { profile_bpf__detach(skel); }
void profile_bpf::destroy(struct profile_bpf *skel) { profile_bpf__destroy(skel); }
const void *profile_bpf::elf_bytes(size_t *sz) { return profile_bpf__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
profile_bpf__assert(struct profile_bpf *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->rodata->kernel_stacks_only) == 1, "unexpected size of 'kernel_stacks_only'");
	_Static_assert(sizeof(s->rodata->user_stacks_only) == 1, "unexpected size of 'user_stacks_only'");
	_Static_assert(sizeof(s->rodata->include_idle) == 1, "unexpected size of 'include_idle'");
	_Static_assert(sizeof(s->rodata->filter_by_pid) == 1, "unexpected size of 'filter_by_pid'");
	_Static_assert(sizeof(s->rodata->filter_by_tid) == 1, "unexpected size of 'filter_by_tid'");
	_Static_assert(sizeof(s->rodata->use_pidns) == 1, "unexpected size of 'use_pidns'");
	_Static_assert(sizeof(s->rodata->pidns_dev) == 8, "unexpected size of 'pidns_dev'");
	_Static_assert(sizeof(s->rodata->pidns_ino) == 8, "unexpected size of 'pidns_ino'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __PROFILE_BPF_SKEL_H__ */
